import java.util.*;

class GeometryFactory {
    static Geometry getInstance(GeometryType type)
    {
        switch (type)
        {
            case SPHERE:
                return new Sphere();
            case CONE:
                return new Cone();
            case CYLINDER:
                return new Cylinder();
            //case RECTANGULAR_PRISM:
                //return new RectangularPrism();
            //case SQUARE_PYRAMID:
                //return new SquarePyramid();
            //case ISOSCELES_TRIANGULAR_PRISM:
                //return new IsoscelesTriangularPrism();
            default:
                return null;
        }
    }
}

public class GeometryCalculator {

    public static GeometryType getGeometryType(Geometry geo)
    {
        if (geo instanceof Sphere) {
            return GeometryType.SPHERE;
        }
        else if (geo instanceof Cone) {
            return GeometryType.CONE;
        }
        else if (geo instanceof Cylinder) {
            return GeometryType.CYLINDER;
        }
        /*else if (geo instanceof RectangularPrism) {
            return GeometryType.RECTANGULAR_PRISM;
        }
        else if (geo instanceof SquarePyramid) {
            return GeometryType.SQUARE_PYRAMID;
        }
        else if (geo instanceof IsoscelesTriangularPrism) {
            return GeometryType.ISOSCELES_TRIANGULAR_PRISM;
        }*/
        else {
            return GeometryType.NONE;
        }
    }

    /*public static GeometryType getUserGeometry()
    {
    	int value = 0;
		Scanner scan = new Scanner(System.in);
		do {
       		try {
				value = scan.nextInt();
       		} catch (Exception e) {
       			System.out.println("ERROR! Valid range 1-6. Please re-enter!");
       			scan.next();
       			continue;
       		}
		} while (value < 1 || value > 6);
        return GeometryType.valueOf(value);
    }*/
    /*
    public static GeometryType getUserGeometry()
    {
    	GeometryType type = null;
		Scanner scan = new Scanner(System.in);
		do {
            System.out.println("Please select geometry [SPHERE, CONE, CYLINDER, RECTANGULAR_PRISM, SQUARE_PYRAMID, ISOSCELES_TRIANGULAR_PRISM]:");
       		try {
				String inputString = scan.nextLine();
				type = GeometryType.nameOf(inputString);
				if (type != null) return type;
       		} catch (Exception e) {
       			System.out.println("ERROR! Please re-enter!");
       			scan.next();
       		}
		} while (type == null);
		return type;
    }
     */
    // print all geometry S.A. and Volume in the list
    public static void calculateAll()
    {
        ArrayList<Geometry> geometryList = new ArrayList<Geometry>();
        geometryList.add(new Sphere(1.5));
        geometryList.add(new Cone(1.5, 2.5));
        geometryList.add(new Cylinder(1.5, 2.5));
        //geometryList.add(new RectangularPrism(2.5, 3.5, 4.5));
        //geometryList.add(new SquarePyramid(5.5, 6.5));
        //geometryList.add(new IsoscelesTriangularPrism(7.5, 8.5, 9.5));

        // foreach item in geometryList
        for (int i = 0; i < geometryList.size(); i++)
        {
            Geometry geo = (Geometry) geometryList.get(i);
            if (geo != null) 
            {
            	geo.printInfo();
            }
        }
    }
    
    // user input geometry to calculate its S.A. and Volume
    public static void calculateByUserInput() 
    {
        ArrayList<Geometry> geometryList = new ArrayList<Geometry>();

        while (!Utility.getUserExitKey())
        {
            // select user geometry
            GeometryType type = Utility.getUserGeometry();
            Geometry geo = GeometryFactory.getInstance(type);

            if (geo != null)
            {
                // get the selected geometry's additional information
                System.out.println("Enter " + type + " additional information to calculate Surface Area and Volume Calculator");
                geo.getAdditionalUserInput();

                // print the selected geometry's S.A. and Volume
                geo.printInfo();
                
                // add user input geometry into geometryList
                geometryList.add(geo);
            }
        }
        
        // foreach item in geometryList
        for (Geometry g : geometryList)
        {
            g.printInfo();
        }
    }
}
